import cx from 'classnames';
import React, { MouseEvent } from 'react';
import { ItemActions } from './ItemActions';
import styles from './calorieRow.scss';

type CalorieRowProps = {
  item: CalorieValue,
  onRowClick?: (item: CalorieValue) => void,
  removeItem: (itemToRemove: CalorieValue) => void,
  isSelected?: boolean
};

function CalorieRow (props: CalorieRowProps) {
  const {
    item,
    isSelected = false,
    onRowClick = Function.prototype,
    removeItem
  } = props;

  const onClick = (event: MouseEvent) => {
    event.stopPropagation();
    onRowClick(item);
  };

  return (
    <div className={cx(styles.calorieRow, {[styles.selected]: isSelected})} {...{onClick}}>
      <ItemActions {...{
        className: cx(
          styles.itemActions,
          {
            [styles.open]: isSelected
          }
        ),
        removeItem: () => removeItem(item)
      }} />

      <div className={styles.itemValues}>
        <div className={styles.title}>{item.title}</div>
        <div>{item.count}</div>
      </div>
    </div>
  );
}

export {
  CalorieRow
};
